@@ -16,6 +16,10 @@
  */
 #ifndef KCGI_H
 #define KCGI_H
+/*
+ * The only visible symbols should be those in this header file.
+ */
+#pragma GCC visibility push(default)
 
 #if !defined(__BEGIN_DECLS)
 #  ifdef __cplusplus
@@ -53,7 +57,7 @@
 /*
  * Build version.
  */
-#define	KCGI_VBUILD	0
+#define	KCGI_VBUILD	3
 
 /*
  * Version string of major.minor.build (as a literal string).
@@ -374,6 +378,7 @@ struct	kpair {
 
 struct	kreq; /* forward declaration */
 struct	kfcgi;
+struct 	kcgi_writer;
 
 struct	kvalid {
 	int		(*valid)(struct kpair *kp);
@@ -578,7 +583,14 @@ int		 kvalid_udouble(struct kpair *);
 int		 kvalid_uint(struct kpair *);
 
 void		 kcgi_writer_disable(struct kreq *);
+void		 kcgi_writer_free(struct kcgi_writer *);
+struct kcgi_writer *kcgi_writer_get(struct kreq *, int);
+enum kcgi_err	 kcgi_writer_putc(struct kcgi_writer *, char);
+enum kcgi_err	 kcgi_writer_puts(struct kcgi_writer *, const char *);
+enum kcgi_err	 kcgi_writer_write(struct kcgi_writer *,
+			const void *, size_t);
 
+int		 khttp_fcgi_getfd(const struct kfcgi *);
 enum kcgi_err	 khttp_fcgi_parse(struct kfcgi *, struct kreq *);
 enum kcgi_err	 khttp_fcgi_init(struct kfcgi **, 
 			const struct kvalid *, size_t,
@@ -746,4 +758,5 @@ char		*kutil_urlpartx(struct kreq *, const char *,
 			__attribute__((deprecated));
 __END_DECLS
 
+#pragma GCC visibility pop /* visibility(default) */
 #endif /*!KCGI_H*/
